<?php
class PushAlert_WebPush_Codeblock_Addblock extends Mage_Core_Block_Template
{
    public function getPAData()
    {
        try {
            $pushalertConfig = Mage::getStoreConfig('admin/pushalert');
            return $pushalertConfig;
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return false;
        }
    }

    public function getCurrentUserId()
    {
        try {
            $currUser = Mage::getSingleton('customer/session')->getCustomer();
            if ($currUser->entity_id) {
                return $currUser->entity_id;
            }
            
            return 0;
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return 0;
        }
    }

    public function paEncrypt($num, $key)
    {
        $output = "";
        for ($i = 0; $i < strlen($num); $i++) {
            $output .= $key[substr($num, $i, 1)];
        }
        
        return $output;
    }

    public function ecommCookie($num)
    {
        $key = Mage::getStoreConfig('admin/pushalert/_pushalert_ecomm_key');
        $encrypted = $this->paEncrypt($num, $key);
        return 'pushalert-ecommerce-' . md5('ecomm_cid_' . $encrypted);
    }

    public function getProductData()
    {
        try {
            //$currency = str_replace("100.00", "", Mage::helper('core')->currency("100", true, false));
            $product = Mage::registry('current_product');
            if ($product != null) {
                $productName = $product->getName();
                $productType = $product->getTypeId() == Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE ? 'variable' : 'simple';
                $variants = array();
                if ($product->getTypeId() == Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE) {
                    //$childProducts = Mage::getResourceSingleton('catalog/product_type_configurable')->getChildrenIds($product->getId());
                    $attributes = $product->getTypeInstance(true)->getConfigurableAttributes($product);
                    $pricesByAttributeValues = array();

                    $basePrice = $product->getFinalPrice();

                    foreach ($attributes as $attribute) {
                        $prices = $attribute->getPrices();
                        foreach ($prices as $price) {
                            if ($price['is_percent']) { //if the price is specified in percents
                                $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'] * $basePrice / 100;
                            } else { //if the price is absolute value
                                $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'];
                            }
                        }
                    }

                    $childProducts = $product->getTypeInstance()->getUsedProducts();

                    foreach ($childProducts as $variant) {
                        //$variantcheck = Mage::getModel('catalog/product')->load($variant->getId());
                        $totalPrice = $basePrice;
                        foreach ($attributes as $attribute) {
                            //get the value for a specific attribute for a simple product
                            $value = $variant->getData($attribute->getProductAttribute()->getAttributeCode());
                            //add the price adjustment to the total price of the simple product
                            if (isset($pricesByAttributeValues[$value])) {
                                $totalPrice += $pricesByAttributeValues[$value];
                            }
                        }
                        
                        $variants[] = array(
                            "variant_id" => $product->isAvailable() ? $variant->getId() : 0,
                            "title" => $productName,
                            "price" => $totalPrice,
                            "price_formatted" => Mage::helper('core')->currency($totalPrice, true, false),
                            "image" => $variant->getImageUrl(),
                            "outofstock" => !($variant->isAvailable() && $product->isAvailable())
                        );
                    }
                }

                $productData = array(
                    "id" => $product->getId(),
                    "variant_id" => $productType == 'simple' ? 0 : $product->getId(),
                    "variants" => $variants,
                    "title" => $productName,
                    "price" => $product->getFinalPrice(),
                    "price_formatted" => Mage::helper('core')->currency($product->getFinalPrice(), true, false),
                    "type" => $productType,
                    "image" => $product->getImageUrl(),
                    "outofstock" => !$product->isAvailable()
                );
                
                return $productData;
            }
            return 0;
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return 0;
        }
    }

    public function paSubscriptionCheck()
    {
        try {
            $cookieId = Mage::getStoreConfig('admin/pushalert/_pushalert_cookie_id');
            $pushalertSubsId = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_id');
            $pushalertSubsStatus = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_status');
            return ((isset($pushalertSubsStatus) && $pushalertSubsStatus == "subscribed") && (isset($pushalertSubsId) && $pushalertSubsId != ""));
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return false;
        }
    }

    public function paCheckOldSubscriptionInit()
    {
        try {
            $cookieId = Mage::getStoreConfig('admin/pushalert/_pushalert_cookie_id');
            $checkPushalertWoo = filter_input(INPUT_GET, 'pushalert_source');
            //Mage::getBaseUrl (Mage_Core_Model_Store::URL_TYPE_WEB
            if (isset($checkPushalertWoo)) {
                Mage::getModel('core/cookie')->set('pushalert_woo', $checkPushalertWoo, 259200, "/", NULL, false, false);
                $_COOKIE['pushalert_woo'] = $checkPushalertWoo;
            }

            if (!$this->paSubscriptionCheck()) {
                return;
            }
            
            $currUserId = $this->getCurrentUserId();
            $paCheckCookie = filter_input(INPUT_COOKIE, $this->ecommCookie($currUserId));
            if ($currUserId != 0 && !isset($paCheckCookie)) {
                $pushalertSubsId = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_id');
                if (isset($pushalertSubsId) && $pushalertSubsId != "") {
                    if ($this->PACheckSubsID($currUserId, $pushalertSubsId)) {
                        Mage::getModel('core/cookie')->set($this->ecommCookie($currUserId), '1', 315360000, '/', NULL, false, false);
                        //setcookie($this->ecommCookie($currUserId), '1', 2147483647, "/", $_SERVER['HTTP_HOST']);
                        $_COOKIE[$this->ecommCookie($currUserId)] = '1';
                        return;
                    }
                }
            }
            //user unsubscribed, removing cookies
            /* if (!isset($paCheckCookie) && $currUserId != 0) {
              Mage::getModel('core/cookie')->set($this->ecommCookie($currUserId), '-5', 604800,'/');
              //setcookie($this->ecommCookie($currUserId), '-5', time() + 604800, "/", $_SERVER['HTTP_HOST']);
              $_COOKIE[$this->ecommCookie($currUserId)] = '-5';
              } */
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    function PACheckSubsID($userId, $subsId)
    {
        $attributes = $this->pushalertGetAttributes($subsId);
        if (isset($attributes['user_id'])) {
            return ($attributes['user_id'] == $userId);
        } else {
            return false;
        }
    }

    function pushalertGetAttributes($subscriber_id)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/attribute/get";

            //POST variables
            $postVars = array(
                "subscriber" => $subscriber_id
            );


            $headers = Array();
            $headers[] = "Authorization: api_key=" . $apiKey;

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $curlUrl);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

            $result = curl_exec($ch);
            $result = json_decode($result, true);

            if ($result['success']) {
                return $result['attributes'];
            } else {
                return false;
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }
}