<?php

class Pushalert_WebPush_Model_Observer
{
    public function checkEnabled()
    {
        try {
            if (Mage::getVersion() >= 2) {
                return false;
            }
            $pushalertConfig = Mage::getStoreConfig('admin/pushalert');
            return $pushalertConfig['pa_wp_enabled'];
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return false;
        }
    }

    public function paEncrypt($num, $key)
    {
        $output = "";
        for ($i = 0; $i < strlen($num); $i++) {
            $output .= $key[substr($num, $i, 1)];
        }
        return $output;
    }

    public function ecommCookie($num)
    {
        $key = Mage::getStoreConfig('admin/pushalert/_pushalert_ecomm_key');
        $encrypted = $this->paEncrypt($num, $key);
        return 'pushalert-ecommerce-' . md5('ecomm_cid_' . $encrypted);
    }

    public function addedCart()
    {
        try {
            if (!$this->paSubscriptionCheck()) {
                return;
            }
            
            $paAbandonedCart = Mage::getStoreConfig('admin/pushalert/_pushalert_abandoned_cart');
            if (!$this->checkEnabled() || $paAbandonedCart != 1) {
                return;
            }
            
            $totalItems = 0;
            $cart = Mage::getSingleton('checkout/session')->getQuote();
            foreach ($cart->getAllVisibleItems() as $item) {
                if ($item->getParentItem()) {
                    continue;
                }
                
                $totalItems++;
            }

            if ($totalItems > 0) {
                $this->paInitAbandonedCart($totalItems);
            } else {
                $this->paClearAbandonedCart();
            }
            
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function paSubscriptionCheck()
    {
        try {
            $cookieId = Mage::getStoreConfig('admin/pushalert/_pushalert_cookie_id');
            $pushalertSubsId = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_id');
            $pushalertSubsStatus = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_status');
            return ((isset($pushalertSubsStatus) && $pushalertSubsStatus == "subscribed") && (isset($pushalertSubsId) && $pushalertSubsId != ""));
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return false;
        }
    }

    public function cartUpdate()
    {
        try {
            if (!$this->paSubscriptionCheck()) {
                return;
            }
            $paAbandonedCart = Mage::getStoreConfig('admin/pushalert/_pushalert_abandoned_cart');
            if (!$this->checkEnabled() || $paAbandonedCart != 1) {
                return;
            }
            
            $totalItems = 0;
            $cart = Mage::getSingleton('checkout/session')->getQuote();
            foreach ($cart->getAllVisibleItems() as $item) {
                if ($item->getParentItem()) {
                    continue;
                }
                $totalItems++;
            }
            
            if ($totalItems == 0) {
                $this->paClearAbandonedCart();
            }
            
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function checkPriceChange(Varien_Event_Observer $observer)
    {
        try {
            $paPriceDrop = Mage::getStoreConfig('admin/pushalert/_pushalert_price_drop');
            if (!$this->checkEnabled() || $paPriceDrop != 1) {
                return;
            }

            $event = $observer->getEvent();
            $product = $event->getProduct();
            $file = "pushalertlog.txt";
            $rewrite = Mage::getModel('core/url_rewrite');
            $productMediaConfig = Mage::getModel('catalog/product_media_config');
            $params = array();
            $params['_current'] = false;

            $changedProduct = Mage::getModel('catalog/product')->load($product->getId());
            $changedProductThumbnail = $changedProduct->getThumbnail();
            $changedProductName = $changedProduct->getName();
            $changedProductUrl = $changedProduct->getProductUrl();
            $originalPrice = $changedProduct->getData('price');
            $currentPrice = $product->getData('price');
            $productType = $product->getTypeId() == Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE ? 'variable' : 'simple';
            if ($productType == 'variable') {
                $attributes = $product->getData('configurable_attributes_data');
                $pricesByAttributeValues = array();
                $basePrice = $product->getFinalPrice();
                $totalCurrentPrice = array();
                $childProducts = $product->getTypeInstance()->getUsedProducts();

                if ($attributes != null) {

                    foreach ($attributes as $attribute) {
                        foreach ($attribute['values'] as $price) {
                            if ($price['is_percent']) { //if the price is specified in percents
                                $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'] * $basePrice / 100;
                            } else { //if the price is absolute value
                                $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'];
                            }
                        }
                    }

                    foreach ($childProducts as $variant) {
//$variantcheck = Mage::getModel('catalog/product')->load($variant->getId());
                        $totalPrice = $basePrice;
                        foreach ($attributes as $attribute) {
//get the value for a specific attribute for a simple product

                            $value = $variant->getData($attribute['attribute_code']);
//add the price adjustment to the total price of the simple product
                            if (isset($pricesByAttributeValues[$value])) {
                                $totalCurrentPrice[$variant->getId()] = $totalPrice + $pricesByAttributeValues[$value];
                            }
                        }
                    }

                    if ($changedProduct != null) {
                        $changedProductType = $changedProduct->getTypeId() == Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE ? 'variable' : 'simple';
                        if ($changedProductType == 'variable') {
                            $attributes = $changedProduct->getTypeInstance(true)->getConfigurableAttributes($changedProduct);
                            $pricesByAttributeValues = array();
                            $basePrice = $changedProduct->getFinalPrice();
                            $totalOldPrice = array();
                            $childProducts = $changedProduct->getTypeInstance()->getUsedProducts();

                            foreach ($attributes as $attribute) {
                                $prices = $attribute->getPrices();
                                foreach ($prices as $price) {
                                    if ($price['is_percent']) { //if the price is specified in percents
                                        $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'] * $basePrice / 100;
                                    } else { //if the price is absolute value
                                        $pricesByAttributeValues[$price['value_index']] = (float) $price['pricing_value'];
                                    }
                                }
                            }

                            foreach ($childProducts as $variant) {
//$variantcheck = Mage::getModel('catalog/product')->load($variant->getId());
                                $totalPrice = $basePrice;
                                foreach ($attributes as $attribute) {
//get the value for a specific attribute for a simple product
                                    $value = $variant->getData($attribute->getProductAttribute()->getAttributeCode());
//add the price adjustment to the total price of the simple product
                                    if (isset($pricesByAttributeValues[$value])) {
                                        $totalOldPrice[$variant->getId()] = $totalPrice + $pricesByAttributeValues[$value];
                                    }
                                }
                            }

                            foreach ($childProducts as $variant) {
                                if ($totalCurrentPrice[$variant->getId()] < $totalOldPrice[$variant->getId()]) {
                                    $url = $changedProductUrl;
                                    $idPath = 'product/' . $changedProduct->getId();
                                    $rewrite->loadByIdPath($idPath);
                                    $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                                    $url = ($parentUrl ? $parentUrl : $url);
//$cart_url = apply_filters('woocommerce_get_cart_url', wc_get_page_permalink('cart'));
                                    $productInfo = array(
                                        'id' => $changedProduct->getId(),
                                        'variant_id' => $variant->getId(),
                                        'title' => $changedProductName,
                                        'price' => $totalCurrentPrice[$variant->getId()],
                                        'price_formatted' => Mage::helper('core')->currency($totalCurrentPrice[$variant->getId()], true, false),
                                        'type' => $productType,
                                        'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                                        'outofstock' => $product->getStockItem()->getIsInStock() ? 0 : 1,
                                        'url' => $url,
                                        'add_to_cart' => $url,
                                        'changed' => 'price',
                                        'currency' => ''
                                    );

                                    //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                                    $this->pushalertProductUpdate($productInfo);
                                }
                            }
                        }
                        
                        return;
                    }
                }
            }

            if ($originalPrice > $currentPrice) {
                $parentIds = Mage::getModel('catalog/product_type_configurable')->getParentIdsByChild($product->getId());
                $productName = $product->getName();

                if (sizeof($parentIds) > 0) {
                    foreach ($parentIds as $parentId) {
                        $url = $changedProductUrl;
                        $idPath = 'product/' . $parentId;
                        $rewrite->loadByIdPath($idPath);
                        $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                        $url = ($parentUrl ? $parentUrl : $url);
//$cart_url = apply_filters('woocommerce_get_cart_url', wc_get_page_permalink('cart'));
                        $productInfo = array(
                            'id' => $parentId,
                            'variant_id' => $product->getId(),
                            'title' => $productName,
                            'price' => $currentPrice,
                            'price_formatted' => Mage::helper('core')->currency($currentPrice, true, false),
                            'type' => $productType,
                            'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                            'outofstock' => $product->getStockItem()->getIsInStock() ? 0 : 1,
                            'url' => $url,
                            'add_to_cart' => $url,
                            'changed' => 'price',
                            'currency' => ''
                        );

                        //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                        $this->pushalertProductUpdate($productInfo);
                    }
                } else {
                    $url = $changedProductUrl;
                    $idPath = 'product/' . $product->getId();
                    $rewrite->loadByIdPath($idPath);
                    $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                    $url = ($parentUrl ? $parentUrl : $url);
//$cart_url = apply_filters('woocommerce_get_cart_url', wc_get_page_permalink('cart'));
                    $productInfo = array(
                        'id' => $product->getId(),
                        'variant_id' => 0,
                        'title' => $productName,
                        'price' => $currentPrice,
                        'price_formatted' => Mage::helper('core')->currency($currentPrice, true, false),
                        'type' => $productType,
                        'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                        'outofstock' => $product->getStockItem()->getIsInStock() ? 0 : 1,
                        'url' => $url,
                        'add_to_cart' => $url,
                        'changed' => 'price',
                        'currency' => ''
                    );

                    //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                    $this->pushalertProductUpdate($productInfo);
                }
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function checkStockChange(Varien_Event_Observer $observer)
    {
        try {
            $paStockChange = Mage::getStoreConfig('admin/pushalert/_pushalert_out_of_stock');
            if (!$this->checkEnabled() || $paStockChange != 1) {
                return;
            }
            $event = $observer->getEvent();
            $stockItem = $event->getItem();
            $file = "pushalertlog.txt";
            $rewrite = Mage::getModel('core/url_rewrite');
            $productMediaConfig = Mage::getModel('catalog/product_media_config');
            $params = array();
            $params['_current'] = false;

            $changedProduct = Mage::getModel('catalog/product')->load($stockItem->getData('product_id'));
            $changedProductUrl = $changedProduct->getProductUrl();
            $changedProductId = $changedProduct->getId();
            $changedProductName = $changedProduct->getName();
            $changedProductPrice = $changedProduct->getData('price');
            $changedProductThumbnail = $changedProduct->getThumbnail();

            $oldStockStatus = $stockItem->getOrigData('is_in_stock') == 1 ? 1 : 0;
            $currentStockStatus = $changedProduct->getData('is_in_stock') == 1 ? 1 : 0;

            //file_put_contents($file, "org:" . $oldStockStatus . " curr:" . $currentStockStatus . PHP_EOL, FILE_APPEND | LOCK_EX);

            if ($oldStockStatus == 0 && $currentStockStatus == 1) {
                $productType = $changedProduct->getTypeId() == Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE ? 'variable' : 'simple';

                if ($productType == 'variable'){
                    $url = $changedProductUrl;
                    $idPath = 'product/' . $changedProductId;
                    $rewrite->loadByIdPath($idPath);
                    $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                    $url = ($parentUrl ? $parentUrl : $url);
                    $productInfo = array(
                        'id' => $changedProductId,
                        'variant_id' => 0,
                        'title' => $changedProductName,
                        'price' => $changedProductPrice,
                        'price_formatted' => Mage::helper('core')->currency($changedProductPrice, true, false),
                        'type' => $productType,
                        'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                        'outofstock' => 0,
                        'url' => $url,
                        'add_to_cart' => $url,
                        'changed' => 'outofstock',
                        'currency' => ''
                    );
                    //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                    $this->pushalertProductUpdate($productInfo);
                } else {
                    $parentIds = Mage::getModel('catalog/product_type_configurable')->getParentIdsByChild($changedProductId);
                    if (sizeof($parentIds) > 0) {
                        foreach ($parentIds as $parentId) {
                            $url = $changedProductUrl;
                            $idPath = 'product/' . $parentId;
                            $rewrite->loadByIdPath($idPath);
                            $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                            $url = ($parentUrl ? $parentUrl : $url);
//$cart_url = apply_filters('woocommerce_get_cart_url', wc_get_page_permalink('cart'));
                            $productInfo = array(
                                'id' => $parentId,
                                'variant_id' => $changedProductId,
                                'title' => $changedProductName,
                                'price' => $changedProductPrice,
                                'price_formatted' => Mage::helper('core')->currency($changedProductPrice, true, false),
                                'type' => $productType,
                                'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                                'outofstock' => 0,
                                'url' => $url,
                                'add_to_cart' => $url,
                                'changed' => 'outofstock',
                                'currency' => ''
                            );
                            //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                            $this->pushalertProductUpdate($productInfo);
                        }
                    } else {
                        $url = $changedProductUrl;
                        $idPath = 'product/' . $changedProductId;
                        $rewrite->loadByIdPath($idPath);
                        $parentUrl = Mage::getUrl($rewrite->getRequestPath(), $params);
                        $url = ($parentUrl ? $parentUrl : $url);
                        $productInfo = array(
                            'id' => $changedProductId,
                            'variant_id' => 0,
                            'title' => $changedProductName,
                            'price' => $changedProductPrice,
                            'price_formatted' => Mage::helper('core')->currency($changedProductPrice, true, false),
                            'type' => $productType,
                            'image' => $productMediaConfig->getMediaUrl($changedProductThumbnail),
                            'outofstock' => 0,
                            'url' => $url,
                            'add_to_cart' => $url,
                            'changed' => 'outofstock',
                            'currency' => ''
                        );
                        //file_put_contents($file, var_export($productInfo, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                        $this->pushalertProductUpdate($productInfo);
                    }
                }
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function checkOrderShipped(Varien_Event_Observer $observer)
    {
        try {
            $paOrderShipment = Mage::getStoreConfig('admin/pushalert/_pushalert_shipment_alert');
            if (!$this->checkEnabled() || $paOrderShipment != 1) {
                return;
            }
            $shipment = $observer->getEvent()->getShipment();
            $order = $shipment->getOrder();
            $customerId = $order->getCustomerId() != NULL ? $order->getCustomerId() : 0;
            if ($customerId != 0) {
                $orderStatusUpdate = array(
                    "order_id" => $order->getIncrementId(),
                    "order_status" => 'shipped',
                    "customer_id" => $customerId,
                    "first_name" => $order->getCustomerFirstname(),
                    "last_name" => $order->getCustomerLastname(),
                    "order_status_url" => Mage::getUrl('sales/order/view', array('order_id' => $order->getId())),
                    "tracking_url" => Mage::getUrl('sales/order/shipment', array('order_id' => $order->getId()))
                );
                //file_put_contents("pushalertlog.txt", var_export($orderStatusUpdate, true) . PHP_EOL, FILE_APPEND | LOCK_EX);
                $this->pushalertTrackOrderShipment($orderStatusUpdate);
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function checkOrderCompleted(Varien_Event_Observer $observer)
    {
        $file = "pushalertlog.txt";
        try {
            $paAbandonedCart = Mage::getStoreConfig('admin/pushalert/_pushalert_abandoned_cart');
            if (!$this->checkEnabled() || $paAbandonedCart != 1) {
                return;
            }
            $checkPushalertWoo = isset($_COOKIE['pushalert_woo']) ? $_COOKIE['pushalert_woo'] : false;

            $order = $observer->getEvent()->getOrder();

            if (($order->getState() == Mage_Sales_Model_Order::STATE_PROCESSING || $order->getState() == Mage_Sales_Model_Order::STATE_COMPLETE) && $checkPushalertWoo) {
                $orderId = $order->getRealOrderId();
                //file_put_contents($file, "Order_id: " . $orderId . " Order_total:" . $order->getGrandTotal() . " Check Woo:" . $checkPushalertWoo . PHP_EOL, FILE_APPEND | LOCK_EX);

                $this->pushalertTrackOrder($orderId, $order->getGrandTotal(), $checkPushalertWoo);
            }
            $this->paClearAbandonedCart();
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function paInitAbandonedCart($totalItems)
    {
        try {
            $cookieId = Mage::getStoreConfig('admin/pushalert/_pushalert_cookie_id');
            $currUser = Mage::getSingleton('customer/session')->getCustomer();
            $pushalertSubsId = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_id');
            //$url = Mage::getUrl('checkout/cart');
            //$cart = Mage::getSingleton('checkout/session')->getQuote();
            $userInfo = array();
            $userInfo['cart_url'] = Mage::getUrl('checkout/cart');
            $userInfo['checkout_url'] = Mage::getUrl('checkout/cart');
            $userInfo['total_items'] = $totalItems;

            if ($currUser->entity_id != NULL && filter_input(INPUT_COOKIE, $this->ecommCookie($currUser->entity_id)) == '1') {
                $userInfo['first_name'] = $currUser->firstname;
                $this->pushalertAddAbandonedCart($currUser->entity_id, $userInfo);
            } else {
                $this->pushalertAddAbandonedCart($pushalertSubsId, $userInfo);
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function pushalertAddAbandonedCart($subscriberId, $userInfo = array())
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/abandonedCart";

//POST variables
            $postVars = array(
                "subscriber" => $subscriberId,
                "extra_info" => json_encode($userInfo)
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {
                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);
                $result = json_decode($result, true);
//return $result['success'];
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function paClearAbandonedCart()
    {
        try {
            $cookieId = Mage::getStoreConfig('admin/pushalert/_pushalert_cookie_id');
            if (!$this->paSubscriptionCheck()) {
                return;
            }

            $currUserId = $this->getCurrentUserId();
            $pushalertSubsId = filter_input(INPUT_COOKIE, 'pushalert_' . $cookieId . 'subs_id');

            if ($currUserId != 0) {
                $this->pushalertRemoveAbandonedCart($currUserId);
            }
            $this->pushalertRemoveAbandonedCart($pushalertSubsId);
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function pushalertRemoveAbandonedCart($subscriberId)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');

            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/abandonedCart/delete";

//POST variables
            $postVars = array(
                "subscriber" => $subscriberId
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {

                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);
                $result = json_decode($result, true);
//return $result['success'];
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function pushalertProductUpdate($productInfo)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/product/update";

//POST variables
            $postVars = array(
                "product_info" => json_encode($productInfo)
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {

                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function pushalertTrackOrder($orderId, $orderTotal, $checkPushalertWoo)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/order";

//POST variables
            $postVars = array(
                "order_id" => $orderId,
                "order_total" => $orderTotal,
                "source" => $checkPushalertWoo
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {
                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);
//return $result['success'];
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function pushalertTrackOrderShipment($orderInfo)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/order/track";

            //POST variables
            $postVars = array(
                "order_info" => json_encode($orderInfo)
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {
                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);
                //return $result['success'];
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

    public function getCurrentUserId()
    {
        try {
            $currUser = Mage::getSingleton('customer/session')->getCustomer();
            if ($currUser->entity_id) {
                return $currUser->entity_id;
            }
            return 0;
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            return 0;
        }
    }

    public function backgroundPost($url)
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $parts = parse_url($url);
//print_r($parts);
            $fp = fsockopen("ssl://" . $parts['host'], isset($parts['port']) ? $parts['port'] : 443, $errno, $errstr, 30);


            if (!$fp) {
                return false;
            } else {
                $out = "POST " . $parts['path'] . " HTTP/1.1\r\n";
                $out .= "Host: " . $parts['host'] . "\r\n";
                $out .= "User-Agent: custom\r\n";
                $out .= "Content-Type: application/x-www-form-urlencoded\r\n";
                $out .= "Authorization: api_key=" . $apiKey . "\r\n";
                $out .= "Content-Length: " . strlen($parts['query']) . "\r\n";
                $out .= "Connection: Close\r\n\r\n";
                if (isset($parts['query']))
                    $out .= $parts['query'];
                fwrite($fp, $out);
                fclose($fp);
                return true;
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }
}