<?php

class Pushalert_WebPush_Adminhtml_ConfigurationController extends Mage_Adminhtml_Controller_Action {

    /**
     * Admin controller index action
     *
     * @access public
     * @return void
     */
    public function saveAction()
    {
        try {
            $params = $this->_request->getParams();
            foreach ($params as $key => $value) {
                Mage::getConfig()->saveConfig('admin/pushalert/' . $key, $value, 'default', 0);
            }
            Mage::getSingleton('core/session')->addSuccess('Settings saved successfully!');
            $this->pushalertEnableEcommerce();
            $this->pushalertLoadSettings();
            Mage::getConfig()->reinit();
			$this->_redirect('webpush/adminhtml_configuration/');
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log',true);
            Mage::getSingleton('core/session')->addError('Some error has occurred, please try again.');
            $this->_redirect('webpush/adminhtml_configuration/');
        }
    }

    public function indexAction()
    {
        $this->loadLayout();
        $this->_setActiveMenu('webpush');
        //var_dump(Mage::getSingleton('core/layout')->getUpdate()->getHandles());
        $this->renderLayout();
    }

    public function generateRandomString($length = 16)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    public function pushalertLoadSettings()
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/settings";

            //POST variables
            $postVars = array(
            );


            $headers = Array();
            $headers[] = "Authorization: api_key=" . $apiKey;

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $curlUrl);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

            $result = curl_exec($ch);
            $result = json_decode($result, true);

            if ($result['success']) {
                foreach ($result['data'] as $key => $value) {
                    Mage::getConfig()->saveConfig('admin/pushalert/' . $key, $value, 'default', 0);
                }
            } else {
                return false;
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log',true);
            Mage::getSingleton('core/session')->addError('Some error has occurred, please try again.');
        }
    }

    public function pushalertEnableEcommerce()
    {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/enableEcommerce";

            //POST variables
            $postVars = array(
                "type" => "magento"
            );


            $headers = Array();
            $headers[] = "Authorization: api_key=" . $apiKey;

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $curlUrl);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

            $result = curl_exec($ch);
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log',true);
            Mage::getSingleton('core/session')->addError('Some error has occurred, please try again.');
        }
    }

    public function _isAllowed()
    {
        return Mage::getSingleton('admin/session')->isAllowed('Pushalert_WebPush');
    }

}
