<?php

class Pushalert_WebPush_Adminhtml_SendpushController extends Mage_Adminhtml_Controller_Action {

    /**
     * Admin controller index action
     *
     * @access public
     * @return void
     */
    public function sendAction() {
        try {
            $params = $this->_request->getParams();
            $url = $this->pushalert_setGetParameter($params["notification_url"], "pushalert_source", "dn");
            $this->pushalert_send_notification_curl($params["notification_title"], $params["notification_message"], $url);
            Mage::getSingleton('core/session')->addSuccess('Notification sent successfully!');
            $this->_redirect('webpush/adminhtml_sendpush/');
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            Mage::getSingleton('core/session')->addError('Some error has occurred, please try again.');
            $this->_redirect('webpush/adminhtml_sendpush/');
        }
    }

    function pushalert_setGetParameter($url, $paramName, $paramValue) {
        if ($paramValue == "") {
            return $url;
        }
        if (strpos($url, $paramName . "=") !== FALSE) {
            $prefix = substr($url, 0, strpos($url, $paramName));
            $suffix = substr($url, strpos($url, $paramName));
            $suffix = substr($suffix, strpos($suffix, "=" + 1));
            $suffix = (strpos($suffix, "&") !== FALSE) ? substr($suffix, strpos($suffix, "&")) : "";
            $url = $prefix . $paramName . "=" . $paramValue . $suffix;
        } else {
            if (strpos($url, "?") !== false) {
                $url = $url . "&" . $paramName . "=" . $paramValue;
            } else {
                $url = $url . "?" . $paramName . "=" . $paramValue;
            }
        }
        return $url;
    }

    public function indexAction() {
        $this->loadLayout();
        $this->_setActiveMenu('webpush');
        //var_dump(Mage::getSingleton('core/layout')->getUpdate()->getHandles());
        $this->renderLayout();
    }

    public function _isAllowed() {
        return Mage::getSingleton('admin/session')->isAllowed('Pushalert_WebPush');
    }

    function pushalert_send_notification_curl($title, $message, $url) {
        try {
            if ($title == "" || $message == "" || $url == "") {
                return false;
            }

            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $curlUrl = "https://api.pushalert.co/rest/v1/send";

            //POST variables
            $postVars = array(
                "title" => $title,
                "message" => $message,
                "url" => $url,
            );

            if (!$this->backgroundPost($curlUrl . "?" . http_build_query($postVars))) {

                $headers = Array();
                $headers[] = "Authorization: api_key=" . $apiKey;

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $curlUrl);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postVars));
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

                $result = curl_exec($ch);

                $output = json_decode($result, true);

                if ($output["result"] == "success") {
                    Mage::getSingleton('core/session')->addSuccess('Notification sent successfully!');
                    $this->_redirect('webpush/adminhtml_sendpush/');
                }
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
            Mage::getSingleton('core/session')->addError('Some error has occurred, please try again.');
            $this->_redirect('webpush/adminhtml_index/');
        }
    }

    public function backgroundPost($url) {
        try {
            $apiKey = Mage::getStoreConfig('admin/pushalert/api_key');
            if (!$apiKey) {
                return false;
            }

            $parts = parse_url($url);
//print_r($parts);
            $fp = fsockopen("ssl://" . $parts['host'], isset($parts['port']) ? $parts['port'] : 443, $errno, $errstr, 30);


            if (!$fp) {
                return false;
            } else {
                $out = "POST " . $parts['path'] . " HTTP/1.1\r\n";
                $out .= "Host: " . $parts['host'] . "\r\n";
                $out .= "User-Agent: custom\r\n";
                $out .= "Content-Type: application/x-www-form-urlencoded\r\n";
                $out .= "Authorization: api_key=" . $apiKey . "\r\n";
                $out .= "Content-Length: " . strlen($parts['query']) . "\r\n";
                $out .= "Connection: Close\r\n\r\n";
                if (isset($parts['query']))
                    $out .= $parts['query'];
                fwrite($fp, $out);
                fclose($fp);
                return true;
            }
        } catch (Exception $e) {
            Mage::log($e->getMessage(), null, 'pushalert-webpush.log', true);
        }
    }

}
